]> git.cryptolib.org Git - avr-crypto-lib.git/blobdiff - des.c
removement of debug/unfinished code
[avr-crypto-lib.git] / des.c
diff --git a/des.c b/des.c
index 0a47906afcb0fbce6d32e2fcaf4ed31ea768b3fe..d4b8ce138f2348ee058ac80b0cb3e2614be1b9f9 100644 (file)
--- a/des.c
+++ b/des.c
@@ -1,10 +1,29 @@
+/* des.c */
+/*
+    This file is part of the Crypto-avr-lib/microcrypt-lib.
+    Copyright (C) 2008  Daniel Otte (daniel.otte@rub.de)
+
+    This program is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 /**
* \file       des.c
* \author     Daniel Otte 
* \date       2007-06-16
* \brief      DES and EDE-DES implementation
  * \par License        
- * GPL
+ * GPLv3 or later
  * 
  */
 #include "config.h"
@@ -1,10 +1,29 @@
 /**
- * \file       des.c
- * \author     Daniel Otte 
- * \date       2007-06-16
- * \brief      DES and EDE-DES implementation
+ * \file        des.c
+ * \author      Daniel Otte
+ * \email       daniel.otte@rub.de
+ * \date        2007-06-16
+ * \brief       DES and EDE-DES implementation
  * \par License        